aboutsummaryrefslogtreecommitdiff
path: root/src/globals.hh
diff options
context:
space:
mode:
authorEelco Dolstra <e.dolstra@tudelft.nl>2003-06-27 13:55:12 +0000
committerEelco Dolstra <e.dolstra@tudelft.nl>2003-06-27 13:55:12 +0000
commit3da9687854e029e9df3b612fd592d2d5a622bb20 (patch)
tree4b51f62373c134bb80ff5aac51ffe613eef755e6 /src/globals.hh
parentbb03c45ca03e038c8b74fc1410f48d02ade4c59b (diff)
* Realisation of File(...) expressions.
Diffstat (limited to 'src/globals.hh')
-rw-r--r--src/globals.hh21
1 files changed, 8 insertions, 13 deletions
diff --git a/src/globals.hh b/src/globals.hh
index b81a78714..3cb231ee2 100644
--- a/src/globals.hh
+++ b/src/globals.hh
@@ -8,15 +8,10 @@ using namespace std;
/* Database names. */
-/* dbRefs :: Hash -> FileName
-
- Maintains a mapping from hashes to filenames within the NixValues
- directory. This mapping is for performance only; it can be
- reconstructed unambiguously. The reason is that names in this
- directory are not printed hashes but also might carry some
- descriptive element (e.g., "aterm-2.0-ae749a..."). Without this
- mapping, looking up a value would take O(n) time because we would
- need to read the entire directory. */
+/* dbRefs :: Hash -> Path
+
+ Maintains a mapping from hashes to paths. This is what we use to
+ resolve CHash(hash) content descriptors. */
extern string dbRefs;
/* dbNFs :: Hash -> Hash
@@ -45,11 +40,11 @@ extern string dbNetSources;
/* Path names. */
-/* nixValues is the directory where all Nix values (both files and
- directories, and both normal and non-normal forms) live. */
-extern string nixValues;
+/* nixStore is the directory where we generally store atomic and
+ derived files. */
+extern string nixStore;
-/* nixLogDir is the directory where we log evaluations. */
+/* nixLogDir is the directory where we log various operations. */
extern string nixLogDir;
/* nixDB is the file name of the Berkeley DB database where we